@@ -20,6 +20,7 @@ import tempfile
 import logging
 import requests
 import json
+import warnings
 
 from six import string_types
 from six.moves.html_parser import HTMLParser
@@ -242,21 +243,27 @@ class JIRA(object):
 
 # ApplicationLinks
 
-    def applicationlinks(self):
+    def applicationlinks(self, cached=True):
         """
         List of application links
         :return: json
         """
 
-        url = self._options['server'] + '/rest/applinks/1.0/applicationlink'
+        # if cached, return the last result
+        if cached and hasattr(self,'_applicationlinks'):
+            return self._applicationlinks
+
+        #url = self._options['server'] + '/rest/applinks/latest/applicationlink'
+        url = self._options['server'] + '/rest/applinks/latest/listApplicationlinks'
+
         headers = copy.deepcopy(self._options['headers'])
         headers['content-type'] = 'application/json;charset=UTF-8'
         r = self._session.get(url, headers=headers)
 
         raise_on_error(r)
 
-        r_json = json.loads(r.text)
-        return r_json
+        self._applicationlinks = json.loads(r.text)
+        return self._applicationlinks
 
 # Attachments
     def attachment(self, id):
@@ -670,8 +677,8 @@ class JIRA(object):
         """
         return self._find_for_resource(RemoteLink, (issue, id))
 
-    @translate_resource_args
-    def add_remote_link(self, issue, object, globalId=None, application=None, relationship=None):
+    # removed the @translate_resource_args because it prevents us from finding information for building a proper link
+    def add_remote_link(self, issue, destination, globalId=None, application=None, relationship=None):
         """
         Add a remote link from an issue to an external application and returns a remote link Resource
         for it. ``object`` should be a dict containing at least ``url`` to the linked external URL and
@@ -681,13 +688,15 @@ class JIRA(object):
         and ``relationship``, see https://developer.atlassian.com/display/JIRADEV/JIRA+REST+API+for+Remote+Issue+Links.
 
         :param issue: the issue to add the remote link to
-        :param object: the link details to add (see the above link for details)
+        :param destination: the link details to add (see the above link for details)
         :param globalId: unique ID for the link (see the above link for details)
         :param application: application information for the link (see the above link for details)
         :param relationship: relationship description for the link (see the above link for details)
         """
+        warnings.warn("broken: see https://bitbucket.org/bspeakmon/jira-python/issue/46 and https://jira.atlassian.com/browse/JRA-38551", Warning)
+
         data = {
-            'object': object
+            'object': destination
         }
         if globalId is not None:
             data['globalId'] = globalId
@@ -696,6 +705,12 @@ class JIRA(object):
         if relationship is not None:
             data['relationship'] = relationship
 
+        for x in self.applicationlinks():
+            if x['displayUrl'] == self._options['server']:
+                data['globalId'] = "appId=%s&issueId=%s" % (x['id'], destination.raw['id'])
+                data['application'] = { 'name': x['name'], 'type':"com.atlassian.jira"}
+                break
+
         url = self._get_url('issue/' + str(issue) + '/remotelink')
         r = self._session.post(url, headers={'content-type': 'application/json'}, data=json.dumps(data))
         raise_on_error(r)
@@ -718,7 +733,7 @@ class JIRA(object):
             params['transitionId'] = id
         if expand is not None:
             params['expand'] = expand
-        return self._get_json('issue/' + str(issue) + '/transitions', params)['transitions']
+        return self._get_json('issue/' + str(issue) + '/transitions', params=params)['transitions']
 
     @translate_resource_args
     def transition_issue(self, issue, transitionId, fields=None, comment=None, **fieldargs):
@@ -1209,9 +1224,9 @@ class JIRA(object):
             "expand": expand
         }
         if json_result:
-            return self._get_json('search', search_params)
+            return self._get_json('search', params=search_params)
 
-        resource = self._get_json('search', search_params)
+        resource = self._get_json('search', params=search_params)
         issues = [Issue(self._options, self._session, raw_issue_json) for raw_issue_json in resource['issues']]
         cnt = len(issues)
         total = resource['total']
@@ -1219,7 +1234,7 @@ class JIRA(object):
             while cnt == maxi:
                 idx += maxi
                 search_params["startAt"] = idx
-                resource = self._get_json('search', search_params)
+                resource = self._get_json('search', params=search_params)
                 issue_batch = [Issue(self._options, self._session, raw_issue_json) for raw_issue_json in resource['issues']]
                 issues.extend(issue_batch)
                 cnt = len(issue_batch)
@@ -1288,7 +1303,7 @@ class JIRA(object):
             'startAt': startAt,
             'maxResults': maxResults
         }
-        r_json = self._get_json('user/assignable/multiProjectSearch', params)
+        r_json = self._get_json('user/assignable/multiProjectSearch', params=params)
         users = [User(self._options, self._session, raw_user_json) for raw_user_json in r_json]
         return users
 
@@ -1440,7 +1455,7 @@ class JIRA(object):
             'includeActive': includeActive,
             'includeInactive': includeInactive
         }
-        r_json = self._get_json('user/search', params)
+        r_json = self._get_json('user/search', params=params)
         users = [User(self._options, self._session, raw_user_json) for raw_user_json in r_json]
         return users
 
@@ -1621,7 +1636,7 @@ class JIRA(object):
         options.update({'path': path})
         return base.format(**options)
 
-    def _get_json(self, path, base=JIRA_BASE_URL, params=None):
+    def _get_json(self, path, params=None, base=JIRA_BASE_URL):
         url = self._get_url(path, base)
         r = self._session.get(url, params=params, headers=self._options['headers'])
         raise_on_error(r)
